@@ -19,7 +19,7 @@ my $has_PDL_stats_basic = $@ ? undef : 1;
 #  to hide the piddle from the caller to avoid arbitrary changes
 #  being applied to it.
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our $Tolerance = 0.0;  #  for compatibility with Stats::Descr, but not used here
 
@@ -160,6 +160,9 @@ sub _mean {
 }
 
 
+sub sd    {return $_[0]->standard_deviation}
+sub stdev {return $_[0]->standard_deviation}
+
 sub _standard_deviation {
     my $self = shift;
 
@@ -296,6 +299,20 @@ sub _mode {
     return $mode;
 }
 
+sub percentiles {
+    my ($self, @percentiles) = @_;
+
+    my $piddle = $self->_get_piddle;
+
+    return
+      if !defined $piddle || $piddle->nelem == 0;
+
+    my @vals = map {$self->percentile($_)} @percentiles;
+
+    return @vals;
+}
+
+
 #  caching wrapper
 #  need to convert $p to fraction, or perhaps die if it is between 0 and 1
 #  hard-coded cache percentiles not ideal
@@ -306,10 +323,14 @@ sub percentile {
     return undef
       if !defined $piddle || $piddle->nelem == 0;
 
-    if (fmod ($p, 5) == 0) {
-        return $self->{_cache}{percentile}{$p}
-          if defined $self->{_cache}{percentile}{$p};
-    }
+    return $self->median
+      if $p == 50;
+
+    die "Percentile $p outside range 0..100"
+      if $p < 0 or $p > 100;
+
+    return $self->{_cache}{percentile}{$p}
+      if defined $self->{_cache}{percentile}{$p};
 
     my $pctl = $self->_percentile($p);
 
@@ -317,7 +338,7 @@ sub percentile {
         $pctl = $pctl->sclr;
     }
 
-    if (fmod ($p, 5) == 0) {
+    if (int ($p) == $p) {
         $self->{_cache}{percentile}{$p} = $pctl;
     }
 
@@ -350,7 +371,7 @@ Statistics::Descriptive using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -432,6 +453,12 @@ Skewness and kurtosis to match that of MS Excel.
 If you are used to R then these are the same as type=2
 in e1071::skewness and e1071::kurtosis.
 
+=item sd
+
+=item stdev
+
+These are aliases for the standard_deviation method.
+
 
 =item percentile (10)
 
@@ -441,6 +468,11 @@ The percentile calculation differs from Statistics::Descriptive in that it uses
 linear interpolation to determine the values, and thus does not
 return the exact same values as the input data.
 
+=item percentiles (10, 20, 30)
+
+A simple wrapper around the percentile method to allow calculation of
+multiple values in one call.
+
 =item iqr
 
 The inter-quartile range.  A convenience method to calculate the
