@@ -18,7 +18,7 @@ use PDL::NiceSlice;
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use parent 'Statistics::Descriptive::PDL::Weighted';
 
@@ -107,6 +107,9 @@ sub _kurtosis {
     return ( $correction1 * $sumpow4 ) - $correction2;
 }
 
+#  crude memoisation - would be nice to use
+#  state but it has issues with lists on older perls
+my %k_piddle_cache;
 
 #  Uses same basic algorithm as PDL::pctl.
 sub _percentile {
@@ -117,8 +120,6 @@ sub _percentile {
     return undef
       if !defined $piddle or $piddle->isempty;
 
-    #return $self->median if $p == 50;
-
     $piddle = $self->_deduplicate_piddle;
 
     my $wt_piddle = $self->_get_weights_piddle;
@@ -132,11 +133,18 @@ sub _percentile {
     my $k = floor $target_wt;
     my $d = $target_wt - $k;
 
-    my $idx = PDL->pdl($k)->vsearch_insert_leftmost($cumsum)->sclr;
+    my $idx = ($k_piddle_cache{$k} //= PDL->pdl(PDL::indx(), [$k]))->vsearch_insert_leftmost($cumsum)->at(0);
+
+    if (scalar keys %k_piddle_cache > 10000) {
+        #  Reset if we get too many
+        #  - could be more nuanced based on frequency
+        #  but then we would have to track it
+        %k_piddle_cache = ();
+    }
 
     #  we need to interpolate if our target weight falls between two sets of weights
     #  e.g. target is 1.3, but the cumulative weights are [1,2] or [1,5]
-    my $fraction = $target_wt - $cumsum->at($idx);
+    my $fraction = $target_wt - ($cumsum->at($idx));
     if ($fraction > 0 && $fraction < 1) {
         my $lower_val = $piddle->at($idx);
         my $upper_val = $piddle->at($idx+1);
@@ -160,7 +168,7 @@ Statistics::Descriptive::PDL::SampleWeighted - Sample weighted descriptive stati
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
