@@ -18,7 +18,7 @@ use PDL::NiceSlice;
 
 ## no critic (ProhibitExplicitReturnUndef)
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use parent 'Statistics::Descriptive::PDL';
 
@@ -206,11 +206,15 @@ sub _deduplicate_piddle {
     my $self = shift;
     my $piddle = $self->_get_piddle;
     
-    return undef if !defined $piddle;
+    return undef
+      if !defined $piddle;
+
+    return $piddle
+      if $self->{_cache}{deduplicated};
 
     my $unique = $piddle->uniq;
 
-    return $self->_get_piddle
+    return $piddle
       if $unique->nelem == $piddle->nelem;
 
     if (!$self->{sorted}) {
@@ -240,6 +244,7 @@ sub _deduplicate_piddle {
     $self->_set_weights_piddle(\@wts);
 
     delete $self->{_cache};
+    $self->{_cache}{deduplicated} = 1;
 
     return $self->_get_piddle;
 }
@@ -345,7 +350,7 @@ sub _percentile {
 
     my $target_wt = $self->sum_weights * ($p / 100);
 
-    my $idx = PDL->pdl($target_wt)->vsearch_insert_leftmost($cumsum->reshape);  
+    my $idx = PDL->pdl($target_wt)->vsearch_insert_leftmost($cumsum->reshape);
 
     return $data->at($idx);
 }
@@ -363,7 +368,7 @@ Statistics::Descriptive::Weighted using PDL as the back-end
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
